@@ -153,6 +153,7 @@ Rcpp::List L0LearnCV(const arma::mat& X, const arma::vec& y, const std::string L
         PG.LambdaU = true;
         PG.XtrAvailable = false; // reset XtrAvailable since its changed upon every call
         PG.LambdasGrid = G.Lambda0;
+        PG.NnzStopNum = p; // remove any constraints on the supp size when fitting over the cv folds
         if (PG.P.Specs.L0 == true){PG.Lambdas = PG.LambdasGrid[0];}
         Grid Gtraining(Xtraining, ytraining, PG);
         Gtraining.Fit();
@@ -183,7 +184,7 @@ Rcpp::List L0LearnCV(const arma::mat& X, const arma::vec& y, const std::string L
   	}
 
 
-    arma::field<arma::vec> CVMeans(Ngamma); // PROBLEM HERE!!!
+    arma::field<arma::vec> CVMeans(Ngamma);
     arma::field<arma::vec> CVSDs(Ngamma);
 
     for(unsigned int i=0; i<Ngamma; ++i)
